==> darwin-shared-0.1.14.tar.gz: darwin-shared-0.1.14/darwin/utils/microservices.py <==
from ..utils.enum import Enum


class Environment(Enum):

    sandbox = "sandbox"
    production = "production"
    development = "development"

    @classmethod
    def current(cls):
        from ..utils.metadata import Metadata
        projectId = Metadata.getProjectId()
        if "-dev" in projectId: return cls.development
        if "-sbx" in projectId: return cls.sandbox
        return cls.production


class Microservice(Enum):

    address = "address"
    workspace = "workspace"
    transfer = "transfer"
    gateway = "gateway"
    charge = "charge"
    team = "team"
    bank = "bank"
    edi = "edi"

    @classmethod
    def getBaseUrl(cls, ms, environment=None):
        return "https://%s.appspot.com" % cls.getProjectId(ms, environment=environment or Environment.current())

    @classmethod
    def getLogoUrl(cls):
        return "https://storage.googleapis.com/%s.appspot.com/logo.png" % Microservice.getProjectId(Microservice.workspace)

    @classmethod
    def getProjectId(cls, ms, environment=None):
        return {
            Environment.production: _productionProjectId.get(ms),
            Environment.development: _developmentProjectId.get(ms),
            Environment.sandbox: _sandboxProjectId.get(ms)
        }[environment or Environment.current()]


class Webapp:

    @classmethod
    def getBaseUrl(cls, environment=None):
        return {
            Environment.production: "https://web.starkbank.com",
            Environment.development: "https://development.web.starkbank.com"
        }[environment or Environment.current()]


_developmentProjectId = {
    Microservice.transfer:  "api-ms-transfer-dev",
    Microservice.charge:    "api-ms-charge-dev",
    Microservice.team:      "api-ms-refund-dev",
    Microservice.workspace: "api-ms-workspace-dev",
    Microservice.bank:      "api-ms-bank-dev",
    Microservice.gateway:   "api-ms-gateway-dev",
    Microservice.edi:       "api-ms-edi-dev",
    Microservice.address:   "api-ms-address-dev"
}

_sandboxProjectId = {
    Microservice.transfer:  "api-ms-transfer-sbx",
    Microservice.charge:    "api-ms-charge-sbx",
    Microservice.team:      "api-ms-refund-sbx",
    Microservice.workspace: "api-ms-workspace-sbx",
    Microservice.bank:      "api-ms-bank-sbx",
    Microservice.gateway:   "api-ms-gateway-sbx",
    Microservice.edi:       "api-ms-edi-sbx",
    Microservice.address:   "api-ms-address-sbx"
}

_productionProjectId = {
    Microservice.transfer:  "api-ms-transfer",
    Microservice.charge:    "api-ms-charge",
    Microservice.team:      "api-ms-refund",
    Microservice.workspace: "api-ms-workspace",
    Microservice.bank:      "api-ms-bank",
    Microservice.gateway:   "api-ms-gateway",
    Microservice.edi:       "api-ms-edi",
    Microservice.address:   "api-ms-address"
}

==> darwin-shared-0.2.21.tar.gz: darwin-shared-0.2.21/darwin/utils/microservices.py <==
from ..utils.enum import Enum


class Environment(Enum):

    sandbox = "sandbox"
    production = "production"
    development = "development"

    @classmethod
    def current(cls):
        from ..utils.metadata import Metadata
        projectId = Metadata.getProjectId()
        if "-dev" in projectId: return cls.development
        if "-sbx" in projectId: return cls.sandbox
        return cls.production


class Microservice(Enum):

    webhook = "webhook"
    address = "address"
    workspace = "workspace"
    transfer = "transfer"
    gateway = "gateway"
    charge = "charge"
    team = "team"
    bank = "bank"
    auth = "auth"
    edi = "edi"
    pdf = "pdf"

    @classmethod
    def getBaseUrl(cls, ms, environment=None):
        return "https://%s.appspot.com" % cls.getProjectId(ms, environment=environment or Environment.current())

    @classmethod
    def getLogoUrl(cls):
        return "https://storage.googleapis.com/%s.appspot.com/logo.png" % Microservice.getProjectId(Microservice.workspace)

    @classmethod
    def getProjectId(cls, ms, environment=None):
        return {
            Environment.production:  _productionProjectId.get(ms),
            Environment.sandbox:     _sandboxProjectId.get(ms),
            Environment.development: _developmentProjectId.get(ms)
        }[environment or Environment.current()]


class Webapp:

    @classmethod
    def getBaseUrl(cls, environment=None):
        return {
            Environment.production:  "https://web.starkbank.com",
            Environment.sandbox:     "https://sandbox.web.starkbank.com",
            Environment.development: "https://development.web.starkbank.com"
        }[environment or Environment.current()]


_developmentProjectId = {
    Microservice.transfer:  "api-ms-transfer-dev",
    Microservice.charge:    "api-ms-charge-dev",
    Microservice.team:      "api-ms-refund-dev",
    Microservice.workspace: "api-ms-workspace-dev",
    Microservice.bank:      "api-ms-bank-dev",
    Microservice.gateway:   "api-ms-gateway-dev",
    Microservice.edi:       "api-ms-edi-dev",
    Microservice.address:   "api-ms-address-dev",
    Microservice.auth:      "api-ms-auth-dev",
    Microservice.webhook:   "api-ms-webhook-dev",
    Microservice.pdf:       "api-ms-pdf-dev"
}

_sandboxProjectId = {
    Microservice.transfer:  "api-ms-transfer-sbx",
    Microservice.charge:    "api-ms-charge-sbx",
    Microservice.team:      "api-ms-refund-sbx",
    Microservice.workspace: "api-ms-workspace-sbx",
    Microservice.bank:      "api-ms-bank-sbx",
    Microservice.gateway:   "api-ms-gateway-sbx",
    Microservice.edi:       "api-ms-edi-sbx",
    Microservice.address:   "api-ms-address-sbx",
    Microservice.auth:      "api-ms-auth-sbx",
    Microservice.webhook:   "api-ms-webhook-sbx",
    Microservice.pdf:       "api-ms-pdf-sbx"
}

_productionProjectId = {
    Microservice.transfer:  "api-ms-transfer",
    Microservice.charge:    "api-ms-charge",
    Microservice.team:      "api-ms-refund",
    Microservice.workspace: "api-ms-workspace",
    Microservice.bank:      "api-ms-bank",
    Microservice.gateway:   "api-ms-gateway",
    Microservice.edi:       "api-ms-edi",
    Microservice.address:   "api-ms-address",
    Microservice.auth:      "api-ms-auth",
    Microservice.webhook:   "api-ms-webhook",
    Microservice.pdf:       "api-ms-pdf"
}
